/* eslint-disable func-names, space-before-function-paren */

window.d3 = require('d3');
